.. _api_handlers:

Bulk Data Handlers
==================

.. deprecated:: 3.0

    The ``pydicom.pixel_data_handlers`` module is deprecated and will be removed
    in v4.0. Use the :mod:`~pydicom.pixels` module instead.

Functions for handling bulk data elements such as (7FE0,0010) *Pixel Data*

.. toctree::
   :maxdepth: 1
   :includehidden:

   handlers.pixel_data
